@@ -8,22 +8,20 @@
  **
  ** See the file "LICENSE" for more information
  **
+ ** $Id: Polygon.java 683 2012-06-24 22:19:28Z mcoletti $
  **/
 package sim.app.geo.schellingpolygon;
 
 import java.util.ArrayList;
-
-import sim.util.geo.AttributeField;
 import sim.util.geo.MasonGeometry;
 
 
 
-
 public class Polygon extends MasonGeometry
 {
-
     int id = -1;
     String soc;
+
     ArrayList<Person> residents;
     ArrayList<Polygon> neighbors;
 
@@ -40,19 +38,8 @@ public class Polygon extends MasonGeometry
 
     public void init()
     {
-        ArrayList<AttributeField> attribs =
-            (ArrayList<AttributeField>) geometry.getUserData();
-        for (AttributeField af : attribs)
-        {
-            if (af.name.equals("ID_ID"))
-            {
-                Double d = (Double) af.value;
-                id = (int) Math.floor(d);
-            } else if (af.name.equals("SOC"))
-            {
-                soc = (String) af.value;
-            }
-        }
+        id = getDoubleAttribute("ID_ID").intValue();
+        soc = getStringAttribute("SOC");
     }
 
 
