@@ -8,6 +8,7 @@
  **
  ** See the file "LICENSE" for more information
  **
+ ** $Id: Tile.java 687 2012-06-25 04:14:18Z mcoletti $
  **/
 package sim.app.geo.sleuth;
 
@@ -23,14 +24,21 @@ public class Tile
     int y;
 
 
-    double slope;
-    double landuse;
+    /**
+     * In range [1,51].  I have no idea why.
+     */
+    int slope;
+
+    /**
+     * One of four values to indicate how this tile is used.
+     */
+    int landuse;
 
     boolean excluded;
 
-    double transport;
+    int transport;
 
-    double hillshade;
+    int hillshade;
 
     boolean urbanOriginally;
 
