@@ -8,7 +8,7 @@
  **
  ** See the file "LICENSE" for more information
  **
- ** $Id: Raindrop.java 690 2012-06-25 04:28:09Z mcoletti $
+ ** $Id: Raindrop.java 722 2012-08-31 17:22:03Z mcoletti $
  **/
 package sim.app.geo.waterworld;
 
@@ -103,8 +103,7 @@ public class Raindrop implements Steppable
         }
 
         // select randomly from the eligible neighbors
-        Random rand = new Random();
-        Basin newbasin = mins.get(rand.nextInt(mins.size()));
+        Basin newbasin = mins.get(state.random.nextInt(mins.size()));
 
         // move to this new spot
         basin.removeDrop(this);
